@@ -1,11 +1,11 @@
 test_that("timestamp string parsing to offsets and deparsing of offsets to timestamps", {
-  # This test tests: global CFtime* constants, CFtime(), CFparse(), CFtimestamp():
+  # This test tests: global CFt* constants, CFtime(), CFparse(), CFtimestamp():
   # decomposing offsets into timestamp elements, generating timestamp strings,
   # parsing timestamp strings back into timestamp elements.
-  for (c in CFtime_calendars) {
-    for (u in unique(CFtime_units$unit_id)) {
-      offsets <- 1:10000 #round(runif(1000, max = 10000), 3)
-      def <- paste(CFtime_unit_string[u], "since 1953-08-20")
+  for (c in CFt$calendars$name) {
+    for (u in unique(CFt$CFunits$id)) {
+      offsets <- 1:10000
+      def <- paste(CFt$units$name[u], "since 1953-08-20")
       cf <- CFtime(def, c, offsets)
       ts <- CFtimestamp(cf, "timestamp")
       cf2 <- CFtime(def, c)
@@ -33,13 +33,13 @@ test_that("testing calendars with leap years", {
 
 test_that("Testing milli-second timestamp string parsing to offsets and deparsing
           of offsets to timestamps", {
-  # This test tests: global CFtime* constants, CFtime(), CFparse(), CFtimestamp():
+  # This test tests: global CFt* constants, CFtime(), CFparse(), CFtimestamp():
   # decomposing offsets into milli-second timestamp elements, generating timestamp strings,
   # parsing timestamp strings back into timestamp elements.
-  for (c in CFtime_calendars) {
+  for (c in CFt$calendars$name) {
     for (u in 3:4) {
       offsets <- runif(10000, max = 10000)
-      def <- paste(CFtime_unit_string[u], "since 1953-08-20 07:34:12.2")
+      def <- paste(CFt$units$name[u], "since 1953-08-20 07:34:12.2")
       cf <- CFtime(def, c, offsets)
       ts <- CFtimestamp(cf, "timestamp")
       cf2 <- CFtime(def, c)
